@@ -8,6 +8,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 import aws_cdk.alexa_ask._jsii
 import aws_cdk.aws_accessanalyzer._jsii
 import aws_cdk.aws_acmpca._jsii
@@ -55,6 +57,7 @@ import aws_cdk.aws_codestarnotifications._jsii
 import aws_cdk.aws_cognito._jsii
 import aws_cdk.aws_config._jsii
 import aws_cdk.aws_connect._jsii
+import aws_cdk.aws_controltower._jsii
 import aws_cdk.aws_cur._jsii
 import aws_cdk.aws_customerprofiles._jsii
 import aws_cdk.aws_databrew._jsii
@@ -80,6 +83,7 @@ import aws_cdk.aws_elasticloadbalancingv2._jsii
 import aws_cdk.aws_elasticsearch._jsii
 import aws_cdk.aws_emr._jsii
 import aws_cdk.aws_emrcontainers._jsii
+import aws_cdk.aws_emrserverless._jsii
 import aws_cdk.aws_events._jsii
 import aws_cdk.aws_eventschemas._jsii
 import aws_cdk.aws_evidently._jsii
@@ -130,6 +134,7 @@ import aws_cdk.aws_logs._jsii
 import aws_cdk.aws_lookoutequipment._jsii
 import aws_cdk.aws_lookoutmetrics._jsii
 import aws_cdk.aws_lookoutvision._jsii
+import aws_cdk.aws_m2._jsii
 import aws_cdk.aws_macie._jsii
 import aws_cdk.aws_managedblockchain._jsii
 import aws_cdk.aws_mediaconnect._jsii
@@ -157,6 +162,7 @@ import aws_cdk.aws_quicksight._jsii
 import aws_cdk.aws_ram._jsii
 import aws_cdk.aws_rds._jsii
 import aws_cdk.aws_redshift._jsii
+import aws_cdk.aws_redshiftserverless._jsii
 import aws_cdk.aws_refactorspaces._jsii
 import aws_cdk.aws_rekognition._jsii
 import aws_cdk.aws_resiliencehub._jsii
@@ -187,9 +193,11 @@ import aws_cdk.aws_ssmcontacts._jsii
 import aws_cdk.aws_ssmincidents._jsii
 import aws_cdk.aws_sso._jsii
 import aws_cdk.aws_stepfunctions._jsii
+import aws_cdk.aws_supportapp._jsii
 import aws_cdk.aws_synthetics._jsii
 import aws_cdk.aws_timestream._jsii
 import aws_cdk.aws_transfer._jsii
+import aws_cdk.aws_voiceid._jsii
 import aws_cdk.aws_waf._jsii
 import aws_cdk.aws_wafregional._jsii
 import aws_cdk.aws_wafv2._jsii
@@ -201,9 +209,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/cloudformation-include",
-    "1.156.1",
+    "1.173.0",
     __name__[0:-6],
-    "cloudformation-include@1.156.1.jsii.tgz",
+    "cloudformation-include@1.173.0.jsii.tgz",
 )
 
 __all__ = [
